<?php

declare(strict_types=1);

namespace Drupal\checklistapi;

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Entity\EntityDescriptionInterface;

/**
 * Defines the interface for checklist entities.
 */
interface ChecklistInterface extends ConfigEntityInterface, EntityDescriptionInterface {

  /**
   * Returns help text or instructions to display with this checklist.
   *
   * @return string
   *   Help text, if any, to display with this checklist.
   */
  public function getHelpText(): string;

  /**
   * Returns the groups under which tasks are, well, grouped.
   *
   * @return array[]
   *   An associative array of arrays. Each sub-array must contain the following
   *   keys:
   *   - title: A human-readable title for the group.
   *   - description: An optional, human-readable description of the group.
   *   - weight: An integer weight of the group, relative to other groups.
   */
  public function getTaskGroups(): array;

  /**
   * Adds a task group.
   *
   * @param string $key
   *   A machine-readable identifier for the group.
   * @param string $title
   *   A human-readable title for the group.
   * @param string $description
   *   (optional) A human-readable description of the group.
   * @param int $weight
   *   (optional) The weight of the group, relative to other groups.
   *
   * @return $this
   */
  public function addTaskGroup(string $key, string $title, string $description = '', int $weight = 0): self;

}
